@@ -102,13 +102,14 @@ class MultipartDecoder:
             re.MULTILINE,
         )
 
-    def __call__(self, data: Optional[bytes] = None) -> None:
+    def __call__(self, data: bytes) -> None:
         if data:
             if self.max_file_size is not None and len(self.buffer) + len(data) > self.max_file_size:
                 raise RequestEntityTooLarge()
             self.buffer.extend(data)
 
-    def _process_preamble(self) -> Optional[MultipartMessageEvent]:
+    def _process_preamble(self) -> Optional[PreambleEvent]:
+        event: Optional[PreambleEvent] = None
         match = self.preamble_re.search(self.buffer, self.search_position)
         if match is not None:
             if match.group(1).startswith(b"--"):
@@ -118,33 +119,44 @@ class MultipartDecoder:
 
             data = bytes(self.buffer[: match.start()])
             del self.buffer[: match.end()]
-            return PreambleEvent(data=data)
-        return None
+            event = PreambleEvent(data=data)
+        if event:
+            self.search_position = 0
+        else:
+            self.search_position = max(0, len(self.buffer) - len(self.message_boundary) - SEARCH_BUFFER_LENGTH)
+        return event
 
-    def _process_part(self) -> Optional[MultipartMessageEvent]:
+    def _process_part(self) -> Optional[Union[FileEvent, FieldEvent]]:
+        event: Optional[Union[FileEvent, FieldEvent]] = None
         match = BLANK_LINE_RE.search(self.buffer, self.search_position)
         if match is not None:
             headers = parse_headers(self.buffer[: match.start()], charset=self.charset)
             del self.buffer[: match.end()]
 
-            content_disposition_header = headers.get("Content-Disposition") or headers.get("content-disposition")
+            content_disposition_header = headers.get("content-disposition")
             if not content_disposition_header:
                 raise ValueError("Missing Content-Disposition header")
 
             _, extra = parse_options_header(content_disposition_header)
             if "filename" in extra:
-                return FileEvent(
+                event = FileEvent(
                     filename=extra["filename"],
                     headers=headers,
                     name=extra.get("name", ""),
                 )
-            return FieldEvent(
-                headers=headers,
-                name=extra.get("name", ""),
-            )
-        return None
+            else:
+                event = FieldEvent(
+                    headers=headers,
+                    name=extra.get("name", ""),
+                )
+        if event:
+            self.search_position = 0
+            self.processing_stage = ProcessingStage.DATA
+        else:
+            self.search_position = max(0, len(self.buffer) - SEARCH_BUFFER_LENGTH)
+        return event
 
-    def _process_data(self) -> Optional[MultipartMessageEvent]:
+    def _process_data(self) -> Optional[DataEvent]:
         match = self.boundary_re.search(self.buffer) if self.buffer.find(b"--" + self.message_boundary) != -1 else None
         if match is not None:
             if match.group(1).startswith(b"--"):
@@ -161,6 +173,12 @@ class MultipartDecoder:
             del self.buffer[:data_length]
         return DataEvent(data=data, more_data=more_data) if data or not more_data else None
 
+    def _process_epilogue(self) -> EpilogueEvent:
+        event = EpilogueEvent(data=bytes(self.buffer))
+        del self.buffer[:]
+        self.processing_stage = ProcessingStage.COMPLETE
+        return event
+
     def next_event(self) -> Optional[MultipartMessageEvent]:
         """Processes the data according the parser's processing_stage. The
         processing_stage is updated according to the parser's processing_stage
@@ -170,30 +188,12 @@ class MultipartDecoder:
         Returns:
             An optional event instance, depending on the processing_stage of the message processing.
         """
-        if self.processing_stage == ProcessingStage.COMPLETE:
-            return None
-
         if self.processing_stage == ProcessingStage.PREAMBLE:
-            event = self._process_preamble()
-            if event:
-                self.search_position = 0
-            else:
-                self.search_position = max(0, len(self.buffer) - len(self.message_boundary) - SEARCH_BUFFER_LENGTH)
-            return event
-
+            return self._process_preamble()
         if self.processing_stage == ProcessingStage.PART:
-            event = self._process_part()
-            if event:
-                self.search_position = 0
-                self.processing_stage = ProcessingStage.DATA
-            else:
-                self.search_position = max(0, len(self.buffer) - SEARCH_BUFFER_LENGTH)
-            return event
-
+            return self._process_part()
         if self.processing_stage == ProcessingStage.DATA:
             return self._process_data()
-
-        event = EpilogueEvent(data=bytes(self.buffer))
-        del self.buffer[:]
-        self.processing_stage = ProcessingStage.COMPLETE
-        return event
+        if self.processing_stage == ProcessingStage.EPILOGUE:
+            return self._process_epilogue()
+        return None
