@@ -24,15 +24,15 @@ class MultipartFormDataParser:
             max_file_size: Max file size allowed.
             charset: Charset used to encode the data.
         """
-        _, options = parse_options_header(headers.get("Content-Type", "") or headers.get("content-type", ""))
-        self.headers = headers
+        self.headers = {k.lower(): v for k, v in headers.items()}
+        _, options = parse_options_header(self.headers.get("content-type", ""))
         self.stream = stream
         self.charset = options.get("charset", charset)
         self.decoder = MultipartDecoder(
             message_boundary=options.get("boundary", ""), max_file_size=max_file_size, charset=charset
         )
 
-    async def _parse_chunk(self) -> List[Tuple[str, Union[str, UploadFile]]]:
+    async def parse(self) -> List[Tuple[str, Union[str, UploadFile]]]:
         """Parses a chunk into a list of items.
 
         Returns:
@@ -45,31 +45,33 @@ class MultipartFormDataParser:
         upload_file: Optional[UploadFile] = None
         while True:
             event = self.decoder.next_event()
-            if not event or isinstance(event, EpilogueEvent):
+            if event is None or isinstance(event, EpilogueEvent):
                 break
             if isinstance(event, FieldEvent):
                 field_name = event.name
-                continue
-            if isinstance(event, FileEvent):
+            elif isinstance(event, FileEvent):
                 field_name = event.name
                 upload_file = UploadFile(
                     filename=event.filename,
-                    content_type=event.headers.get("Content-Type", "") or event.headers.get("content-type", ""),
+                    content_type=event.headers.get("content-type", ""),
                     headers=event.headers,
                 )
-                continue
-            if isinstance(event, DataEvent):
-                if upload_file is None:
-                    data.extend(event.data)
-                    if not event.more_data:
-                        items.append((field_name, data.decode(self.charset)))
-                        data.clear()
-                else:
+            elif isinstance(event, DataEvent):
+                if upload_file:
                     await upload_file.write(event.data)
                     if not event.more_data:
                         await upload_file.seek(0)
                         items.append((field_name, upload_file))
                         upload_file = None
+                        data.clear()
+                else:
+                    data.extend(event.data)
+                    if not event.more_data:
+                        try:
+                            items.append((field_name, data.decode(self.charset)))
+                        except UnicodeDecodeError:
+                            items.append((field_name, data.decode("latin-1")))
+                        data.clear()
         return items
 
     async def __call__(self) -> List[Tuple[str, Union[str, UploadFile]]]:
@@ -78,8 +80,6 @@ class MultipartFormDataParser:
         Returns:
             A list of tuples, each containing the field name and its value - either a string or an upload file datum.
         """
-        parse_result: List[Tuple[str, Union[str, UploadFile]]] = []
         async for chunk in self.stream:
             self.decoder(chunk)
-            parse_result.extend(await self._parse_chunk())
-        return parse_result
+        return await self.parse()
